@@ -1,5 +1,5 @@
 package Curio::Role;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =encoding utf8
 
@@ -113,17 +113,22 @@ sub keys {
 1;
 __END__
 
-=head1 SUPPORT
-
-See L<Curio/SUPPORT>.
-
-=head1 AUTHORS
-
-See L<Curio/AUTHORS>.
-
 =head1 COPYRIGHT AND LICENSE
 
-See L<Curio/COPYRIGHT AND LICENSE>.
+Copyright (C) 2019 Aran Clary Deltac
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
